==> coder-cli-dev-template-vue3-admin-ts-1.0.0.tgz: package/template/src/stores/user/index.ts <==
import md5 from 'md5'
import router from '@/router'
import { resetRouter } from '@/router'
import { defineStore } from 'pinia'
import { getUserInfo, login } from '@/service/user'
import type { IAccount, IState } from '@/global/types/user'
import { localCache, setTimeStamp } from '@/utils'
import {
  TIME_STAMP,
  USER_STORE_CACHE_KEY,
  APP_STORE_CACHE_KEY,
  THEME_STORE_CACHE_KEY,
  PERMISSION_STORE_CACHE_KEY
} from '@/global/constants'
import useAppStore from '../app'
import useThemeStore from '../theme'
import usePermissionStore from '../permission'

const useUserStore = defineStore('user', {
  state: (): IState => ({
    userInfo: {},
    // https://developer.mozilla.org/zh-CN/docs/Web/JavaScript/Reference/Operators/Nullish_coalescing
    // 空值合并运算符 ?? 的作用: 当左值为 null/undefined 时返回右值
    token: ''
  }),
  // getter 中可以通过 this 或者参数1 state 访问 state
  // getter 中可以通过 this 访问 getter
  getters: {
    // 判断 userInfo 是否为空
    hasUserInfo: (state) => {
      return JSON.stringify(state.userInfo) !== '{}'
    }
  },
  // action 中可以通过 this 直接访问 states/getters/actions
  actions: {
    async login({ username, password }: IAccount) {
      try {
        const { token } = await login({ username, password: md5(password) })
        this.token = token
        // 登录成功, 保存登录时间戳
        setTimeStamp()
      } catch (error) {
        return Promise.reject(error)
      }
    },
    async getUserInfo() {
      try {
        const data = await getUserInfo(this.token)
        this.userInfo = data
        return data
      } catch (error) {
        return Promise.reject(error)
      }
    },
    logout() {
      // 移除动态添加的路由
      resetRouter()
      // 注: 当前项目使用了持久化储存插件,
      // 所以 state 和 浏览器本地缓存 之间会自动同步, 退出时, 需要根据 Store 的 key 清除本地缓存数据
      // https://pinia.vuejs.org/api/interfaces/pinia._StoreWithState.html#-reset
      const appStore = useAppStore()
      const themeStore = useThemeStore()
      const permissionStore = usePermissionStore()
      // 移除插入的 styleEl (主题色设置时插入的元素)
      if (themeStore.styleEl instanceof HTMLStyleElement) {
        themeStore.styleEl.remove()
      }
      themeStore.setStyleEl(null)
      // 重置所有 store
      this.$reset()
      appStore.$reset()
      themeStore.$reset()
      permissionStore.$reset()
      // 直接清除无法生效, 估计是 pinia-plugin-persistedstate 对数据的同步操作是异步执行的
      // 所以将其放到一个微任务中执行, 即可生效
      Promise.resolve().then(() => {
        localCache.removeCache(USER_STORE_CACHE_KEY)
        localCache.removeCache(APP_STORE_CACHE_KEY)
        localCache.removeCache(THEME_STORE_CACHE_KEY)
        localCache.removeCache(PERMISSION_STORE_CACHE_KEY)
        localCache.removeCache(TIME_STAMP) // 这个可以移出 Promise 外
        localCache.removeCache('TOAST UI editor for localhost: Statistics') // 这个可以移出 Promise 外
      })

      // 跳转登录页
      router.push('/login')
    }
  },
  // 不对当前 Store 进行持久化存储
  persist: {
    key: USER_STORE_CACHE_KEY, // 指定浏览器本地缓存使用的 key
    // 用于指定 state 中哪些数据需要被持久化。`[]` 表示不持久化任何状态，`undefined` 或 `null` 表示持久化整个 state。
    // 默认值是 undefined
    paths: ['token']
  }
})

export default useUserStore

==> coder-cli-dev-template-vue3-admin-ts-1.0.1.tgz: package/template/src/stores/user/index.ts <==
import MD5 from 'md5-es'
import router from '@/router'
import { resetRouter } from '@/router'
import { defineStore } from 'pinia'
import { getUserInfo, login } from '@/service/user'
import type { IAccount, IState } from '@/global/types/user'
import { localCache, setTimeStamp } from '@/utils'
import {
  TIME_STAMP,
  USER_STORE_CACHE_KEY,
  APP_STORE_CACHE_KEY,
  THEME_STORE_CACHE_KEY,
  PERMISSION_STORE_CACHE_KEY
} from '@/global/constants'
import useAppStore from '../app'
import useThemeStore from '../theme'
import usePermissionStore from '../permission'

const useUserStore = defineStore('user', {
  state: (): IState => ({
    userInfo: {},
    // https://developer.mozilla.org/zh-CN/docs/Web/JavaScript/Reference/Operators/Nullish_coalescing
    // 空值合并运算符 ?? 的作用: 当左值为 null/undefined 时返回右值
    token: ''
  }),
  // getter 中可以通过 this 或者参数1 state 访问 state
  // getter 中可以通过 this 访问 getter
  getters: {
    // 判断 userInfo 是否为空
    hasUserInfo: (state) => {
      return JSON.stringify(state.userInfo) !== '{}'
    }
  },
  // action 中可以通过 this 直接访问 states/getters/actions
  actions: {
    async login({ username, password }: IAccount) {
      try {
        const { token } = await login({ username, password: MD5.hash(password) })
        this.token = token
        // 登录成功, 保存登录时间戳
        setTimeStamp()
      } catch (error) {
        return Promise.reject(error)
      }
    },
    async getUserInfo() {
      try {
        const data = await getUserInfo(this.token)
        this.userInfo = data
        return data
      } catch (error) {
        return Promise.reject(error)
      }
    },
    logout() {
      // 移除动态添加的路由
      resetRouter()
      // 注: 当前项目使用了持久化储存插件,
      // 所以 state 和 浏览器本地缓存 之间会自动同步, 退出时, 需要根据 Store 的 key 清除本地缓存数据
      // https://pinia.vuejs.org/api/interfaces/pinia._StoreWithState.html#-reset
      const appStore = useAppStore()
      const themeStore = useThemeStore()
      const permissionStore = usePermissionStore()
      // 移除插入的 styleEl (主题色设置时插入的元素)
      if (themeStore.styleEl instanceof HTMLStyleElement) {
        themeStore.styleEl.remove()
      }
      themeStore.setStyleEl(null)
      // 重置所有 store
      this.$reset()
      appStore.$reset()
      themeStore.$reset()
      permissionStore.$reset()
      // 直接清除无法生效, 估计是 pinia-plugin-persistedstate 对数据的同步操作是异步执行的
      // 所以将其放到一个微任务中执行, 即可生效
      Promise.resolve().then(() => {
        localCache.removeCache(USER_STORE_CACHE_KEY)
        localCache.removeCache(APP_STORE_CACHE_KEY)
        localCache.removeCache(THEME_STORE_CACHE_KEY)
        localCache.removeCache(PERMISSION_STORE_CACHE_KEY)
        localCache.removeCache(TIME_STAMP) // 这个可以移出 Promise 外
        localCache.removeCache('TOAST UI editor for localhost: Statistics') // 这个可以移出 Promise 外
      })

      // 跳转登录页
      router.push('/login')
    }
  },
  // 不对当前 Store 进行持久化存储
  persist: {
    key: USER_STORE_CACHE_KEY, // 指定浏览器本地缓存使用的 key
    // 用于指定 state 中哪些数据需要被持久化。`[]` 表示不持久化任何状态，`undefined` 或 `null` 表示持久化整个 state。
    // 默认值是 undefined
    paths: ['token']
  }
})

export default useUserStore
